<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="219"/>
        <source>Drop Error</source>
        <translation type="unfinished">Slipfejl</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="220"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Fil/URL &apos;%1&apos; kan ikke indlejres i HurtigStart lige nu</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="327"/>
        <source>Drop application
icons here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="52"/>
        <source>Move left</source>
        <translation>Flyt mod venstre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>Move right</source>
        <translation>Flyt mod højre</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="59"/>
        <source>Remove from quicklaunch</source>
        <translation>Fjern fra Hurtigstart</translation>
    </message>
</context>
</TS>
